==> kubernetes-model-core-5.11.0-sources.jar: io/fabric8/kubernetes/api/model/AuthInfoBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AuthInfoBuilder extends io.fabric8.kubernetes.api.model.AuthInfoFluentImpl<io.fabric8.kubernetes.api.model.AuthInfoBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.AuthInfo,io.fabric8.kubernetes.api.model.AuthInfoBuilder>{
  public AuthInfoBuilder() {
    this(false);
  }
  public AuthInfoBuilder(java.lang.Boolean validationEnabled) {
    this(new AuthInfo(), validationEnabled);
  }
  public AuthInfoBuilder(io.fabric8.kubernetes.api.model.AuthInfoFluent<?> fluent) {
    this(fluent, false);
  }
  public AuthInfoBuilder(io.fabric8.kubernetes.api.model.AuthInfoFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AuthInfo(), validationEnabled);
  }
  public AuthInfoBuilder(io.fabric8.kubernetes.api.model.AuthInfoFluent<?> fluent,io.fabric8.kubernetes.api.model.AuthInfo instance) {
    this(fluent, instance, false);
  }
  public AuthInfoBuilder(io.fabric8.kubernetes.api.model.AuthInfoFluent<?> fluent,io.fabric8.kubernetes.api.model.AuthInfo instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAs(instance.getAs()); 
    fluent.withAsGroups(instance.getAsGroups()); 
    fluent.withAsUserExtra(instance.getAsUserExtra()); 
    fluent.withAuthProvider(instance.getAuthProvider()); 
    fluent.withClientCertificate(instance.getClientCertificate()); 
    fluent.withClientCertificateData(instance.getClientCertificateData()); 
    fluent.withClientKey(instance.getClientKey()); 
    fluent.withClientKeyData(instance.getClientKeyData()); 
    fluent.withExec(instance.getExec()); 
    fluent.withExtensions(instance.getExtensions()); 
    fluent.withPassword(instance.getPassword()); 
    fluent.withToken(instance.getToken()); 
    fluent.withTokenFile(instance.getTokenFile()); 
    fluent.withUsername(instance.getUsername()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AuthInfoBuilder(io.fabric8.kubernetes.api.model.AuthInfo instance) {
    this(instance,false);
  }
  public AuthInfoBuilder(io.fabric8.kubernetes.api.model.AuthInfo instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAs(instance.getAs()); 
    this.withAsGroups(instance.getAsGroups()); 
    this.withAsUserExtra(instance.getAsUserExtra()); 
    this.withAuthProvider(instance.getAuthProvider()); 
    this.withClientCertificate(instance.getClientCertificate()); 
    this.withClientCertificateData(instance.getClientCertificateData()); 
    this.withClientKey(instance.getClientKey()); 
    this.withClientKeyData(instance.getClientKeyData()); 
    this.withExec(instance.getExec()); 
    this.withExtensions(instance.getExtensions()); 
    this.withPassword(instance.getPassword()); 
    this.withToken(instance.getToken()); 
    this.withTokenFile(instance.getTokenFile()); 
    this.withUsername(instance.getUsername()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.AuthInfoFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.AuthInfo build() {
    AuthInfo buildable = new AuthInfo(fluent.getAs(),fluent.getAsGroups(),fluent.getAsUserExtra(),fluent.getAuthProvider(),fluent.getClientCertificate(),fluent.getClientCertificateData(),fluent.getClientKey(),fluent.getClientKeyData(),fluent.getExec(),fluent.getExtensions(),fluent.getPassword(),fluent.getToken(),fluent.getTokenFile(),fluent.getUsername());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AuthInfoBuilder that = (AuthInfoBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/AuthInfoBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AuthInfoBuilder extends io.fabric8.kubernetes.api.model.AuthInfoFluentImpl<io.fabric8.kubernetes.api.model.AuthInfoBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.AuthInfo,io.fabric8.kubernetes.api.model.AuthInfoBuilder>{
  public AuthInfoBuilder() {
    this(false);
  }
  public AuthInfoBuilder(java.lang.Boolean validationEnabled) {
    this(new AuthInfo(), validationEnabled);
  }
  public AuthInfoBuilder(io.fabric8.kubernetes.api.model.AuthInfoFluent<?> fluent) {
    this(fluent, false);
  }
  public AuthInfoBuilder(io.fabric8.kubernetes.api.model.AuthInfoFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AuthInfo(), validationEnabled);
  }
  public AuthInfoBuilder(io.fabric8.kubernetes.api.model.AuthInfoFluent<?> fluent,io.fabric8.kubernetes.api.model.AuthInfo instance) {
    this(fluent, instance, false);
  }
  public AuthInfoBuilder(io.fabric8.kubernetes.api.model.AuthInfoFluent<?> fluent,io.fabric8.kubernetes.api.model.AuthInfo instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAs(instance.getAs()); 
    fluent.withAsGroups(instance.getAsGroups()); 
    fluent.withAsUid(instance.getAsUid()); 
    fluent.withAsUserExtra(instance.getAsUserExtra()); 
    fluent.withAuthProvider(instance.getAuthProvider()); 
    fluent.withClientCertificate(instance.getClientCertificate()); 
    fluent.withClientCertificateData(instance.getClientCertificateData()); 
    fluent.withClientKey(instance.getClientKey()); 
    fluent.withClientKeyData(instance.getClientKeyData()); 
    fluent.withExec(instance.getExec()); 
    fluent.withExtensions(instance.getExtensions()); 
    fluent.withPassword(instance.getPassword()); 
    fluent.withToken(instance.getToken()); 
    fluent.withTokenFile(instance.getTokenFile()); 
    fluent.withUsername(instance.getUsername()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AuthInfoBuilder(io.fabric8.kubernetes.api.model.AuthInfo instance) {
    this(instance,false);
  }
  public AuthInfoBuilder(io.fabric8.kubernetes.api.model.AuthInfo instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAs(instance.getAs()); 
    this.withAsGroups(instance.getAsGroups()); 
    this.withAsUid(instance.getAsUid()); 
    this.withAsUserExtra(instance.getAsUserExtra()); 
    this.withAuthProvider(instance.getAuthProvider()); 
    this.withClientCertificate(instance.getClientCertificate()); 
    this.withClientCertificateData(instance.getClientCertificateData()); 
    this.withClientKey(instance.getClientKey()); 
    this.withClientKeyData(instance.getClientKeyData()); 
    this.withExec(instance.getExec()); 
    this.withExtensions(instance.getExtensions()); 
    this.withPassword(instance.getPassword()); 
    this.withToken(instance.getToken()); 
    this.withTokenFile(instance.getTokenFile()); 
    this.withUsername(instance.getUsername()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.AuthInfoFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.AuthInfo build() {
    AuthInfo buildable = new AuthInfo(fluent.getAs(),fluent.getAsGroups(),fluent.getAsUid(),fluent.getAsUserExtra(),fluent.getAuthProvider(),fluent.getClientCertificate(),fluent.getClientCertificateData(),fluent.getClientKey(),fluent.getClientKeyData(),fluent.getExec(),fluent.getExtensions(),fluent.getPassword(),fluent.getToken(),fluent.getTokenFile(),fluent.getUsername());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AuthInfoBuilder that = (AuthInfoBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
